@@ -27,8 +27,8 @@ impl Debug for HandleBox {
     }
 }
 
-pub trait MiddleWare: Send + Sync + Debug {
-    //if you take res. handle be done
+pub trait MiddleWare: Send + Sync {
+    /// if you call take Response, next handle will be not run
     fn handle(&self, req: &mut Request, res: &mut Option<Response>);
 }
 
@@ -38,20 +38,28 @@ impl<T: MiddleWare> MiddleWare for Arc<T> {
     }
 }
 
-impl<T: MiddleWare> MiddleWare for Box<T> {
+impl<F> MiddleWare for F where F: Fn(&mut Request, &mut Option<Response>), F: Sync + Send {
     fn handle(&self, req: &mut Request, res: &mut Option<Response>) {
-        T::handle(self, req, res)
+        self(req, res)
     }
 }
 
-
-#[derive(Debug)]
 pub struct Route {
     pub container: SyncHashMap<String, Arc<Box<dyn Any>>>,
     pub middleware: Vec<Box<dyn MiddleWare>>,
     pub handlers: SyncHashMap<String, HandleBox>,
 }
 
+impl Debug for Route {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("Route")
+            .field("container",&self.container.len())
+            .field("middleware",&self.middleware.len())
+            .field("handlers",&self.handlers)
+            .finish()
+    }
+}
+
 
 impl Route {
     pub fn new() -> Self {
@@ -88,6 +96,16 @@ impl Route {
         });
     }
 
+    /// if you take Response. handle be done
+    /// for example:
+    /// ```rust
+    /// use mco_http::server::{Request, Response};
+    /// use mco_http::route::Route;
+    /// let mut route = Route::new();
+    /// route.add_middleware(|req: &mut Request, res: &mut Option<Response>|{
+    ///        ///res.take() //take Response, next handle will be not run
+    ///     });
+    /// ```
     pub fn add_middleware<M: MiddleWare + 'static>(&mut self, m: M) {
         self.middleware.push(Box::new(m));
     }
